marktools.get_noncontext_marks_attached_to_component
====================================================

.. autofunction:: abjad.tools.marktools.get_noncontext_marks_attached_to_component.get_noncontext_marks_attached_to_component
